@@ -3,8 +3,8 @@ use strict;
 use warnings;
 use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use Gtk2 -init;
-use Log::Log4perl;
-Log::Log4perl->init("log.conf");
+use Log::Log4perl qw(:easy);
+Log::Log4perl->easy_init($DEBUG);
 #use Devel::Cycle;
 #use lib "../lib/";
 
