@@ -9,8 +9,8 @@ use Dbc::Schema;
 
 #use lib "../lib/";
 use DataAccess::Dbc::Service;
-use Log::Log4perl;
-Log::Log4perl->init("log_ex2.conf");
+use Log::Log4perl qw(:easy);
+Log::Log4perl->easy_init($DEBUG);
 
 use Forms::Langues2;
 
