@@ -4,8 +4,8 @@ use warnings;
 use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use Gtk2 -init;
 use DBI;
-use Log::Log4perl;
-Log::Log4perl->init("log_ex2.conf");
+use Log::Log4perl qw(:easy);
+Log::Log4perl->easy_init($DEBUG);
 use Forms::Langues2;
 use DataAccess::Dbi::Service;
 
