@@ -11,11 +11,11 @@ use warnings;
 
 =head1 VERSION
 
-version  0.110 but see version at the end of MYMETA.yml to check that I'm correct here...
+version  0.111 
 
 =cut
 
-our $VERSION     = '0.110';
+our $VERSION     = '0.111';
 $VERSION = eval $VERSION;
 
 1;
@@ -37,14 +37,16 @@ On windows use nmake or dmake instead of make.
 
 The following modules are required in order to use Gtk2::Ex::Linker
 
-	Gtk2::Ex::DbLinker::DbTools => 0.104
+	Gtk2::Ex::DbLinker::DbTools => latest version (see README)
 	DateTime::Format::Strptime => 1.5,
 	Test::More => 1,
 	Gtk2 => 1.240,
-	Carp => 1.17,
 	Log::Log4perl => 1.41,
 	Data::Dumper' => 2.154,
 	DBD::SQLite'	=> 1.46
+    Scalar::Util => 1.45
+    Class::InsideOut => 1.13,
+    
 
 Install one of Rose::DB::Object or DBIx::Class if you want to use these orm to access your data.
 
@@ -119,7 +121,7 @@ C<runexample2_dbc.pl> uses DBIx::Class and Gtk2::Ex::DbLinker::DbcDataManager. T
 
 =item *
 
-C<runexample2_sqla.pl uses SQL::Abstract::More and Gtk2::Ex::DbLinker::SqlADataManager. The database is the same as above.
+C<runexample2_sqla.pl> uses SQL::Abstract::More and Gtk2::Ex::DbLinker::SqlADataManager. The database is the same as above.
 
 =item *
 
