@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 use Gtk2::Ex::DbLinker::DatasheetHelper;
-use Carp;
+#use Carp;
 use Glib qw/TRUE FALSE/;
 
 #use Data::Dumper;
@@ -758,8 +758,8 @@ This object is used to instanciante a RdbDataManager, that will be used in the d
       	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data => $datasheet_rows, meta => Rdb::Mytable->meta );
 
 We create the RdbDataManager for the combo rows
-     
-       	my $combo_data = Rdb::Combotable::Manager->get_combotable( select => [qw/t1.id t1.name/], sort_by => 'name');
+
+    my $combo_data = Rdb::Combotable::Manager->get_combotable( select => [qw/t1.id t1.name/], sort_by => 'name');
 	my $dman_combo_1 = Gtk2::Ex::DbLinker::RdbDataManager->new(data => $combo_data, meta => Rdb::Combotable->meta);
 
 
@@ -926,7 +926,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 by FranE<ccedil>ois Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2014-2017 by FranE<ccedil>ois Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
