@@ -7,10 +7,10 @@ use strict;
 use warnings;
 use parent 'Gtk2::Ex::DbLinker::AbForm';
 use Glib qw/TRUE FALSE/;
-use Carp qw(croak confess carp);
+# use Carp qw(croak confess carp);
 
 #use DateTime::Format::Strptime;
-use Data::Dumper;
+#use Data::Dumper;
 my %fieldtype = (
     varchar   => "Glib::String",
     char      => "Glib::String",
@@ -241,10 +241,10 @@ sub _init {
         $self->{cols} = \@col;
     }
 =cut
-    $log{ $id }->debug( "_init: cols ", Dumper @{ $self->_cols  } );
+    $log{ $id }->debug( "_init: cols ", join(" ", @{ $self->_cols  }) );
     $self->_bind_on_changed;
     $self->_set_recordspinner;
-    croak __PACKAGE__ . ": a data manager is required"
+    $log{ $id }->logcroak( __PACKAGE__ . ": a data manager is required")
       unless ( defined $self->_dman );
     $self->_dman->set_row_pos(0);
 }
@@ -258,7 +258,7 @@ sub add_combo_values {
     my $wref       = ref $w;
     my @supp_class = (qw/Gtk2::ComboBox Gtk2::ComboBoxEntry/);
     my %supported  = map { $_ => 1 } @supp_class;
-    confess(
+    $log{ $id }->logconfess(
         "only " . join( " ", @supp_class ) . " supported by add_combo_values" )
       unless ( $supported{$wref} );
     if ( $wref eq "Gtk2::ComboBox" ) {
@@ -328,7 +328,7 @@ sub add_combo {
             $self->_datawidgets( $combo->{id} , $w);
             $self->_datawidgetsName( $combo->{id},  $name);
         } else {
-            croak "no widget found for combo " . $combo->{id};
+            $log{ $id }->logcroak( "no widget found for combo " . $combo->{id});
         }
     } 
     else {
@@ -336,15 +336,15 @@ sub add_combo {
     }
 
     $log{ $id }->debug( "cols: " . join( " ", @cols ) );
-    $log{ $id }->debug( Dumper $self->_datawidgets );
+    # $log{ $id }->debug( sub { Dumper $self->_datawidgets } );
     my $w = $self->_datawidgets( $combo->{id} );
 
     # $log{ $id }->debug( Dumper $self->{datawidgets});
     # die Dumper $w;
-    croak( 'no widget found for combo ' . $combo->{id} ) unless ($w);
+    $log{ $id }->logcroak( 'no widget found for combo ' . $combo->{id} ) unless ($w);
 
     #my @col = @{$self->{cols}};
-    croak("no fields found for combo $combo->{id}") unless (@cols);
+    $log{ $id }->logcroak("no fields found for combo $combo->{id}") unless (@cols);
     my $lastfield = @cols;
 
     #the column to show is either the first (pos 0) if it's the only column or
@@ -767,7 +767,7 @@ In the main form:
 	}
 
 In the subform_a module
-	
+
     sub synchronize_with {
 	my ($self,$value) = @_;
 	my $data = Rdb::Product::Manager->get_product(with_objects => ['seller_product'], query => ['seller_product.no_seller' => {eq => $value}]);
@@ -992,7 +992,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 by F. Rappaz.  All rights reserved.
+Copyright (c) 2014-2017 by F. Rappaz.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
